@@ -35,6 +35,16 @@ def to_id(field):
     return "%s_%s" % (getattr(field, "_tablename", field.tablename), field.name)
 
 
+def compat_represent(field, value, row):
+    represent = field.represent
+    if not represent:
+        return value or ""
+    try:
+        return represent(value, row)
+    except TypeError:
+        return represent(value)
+
+
 def get_options(validators):
     """given a validator chain, if one has .options, return them"""
     options = None
@@ -242,7 +252,9 @@ class FileUploadWidget:
 
             control.append(download_div)
 
-        control.append(LABEL("Change: "))
+            control.append(LABEL("Change: "))
+        else:
+            control.append(LABEL("Upload: "))
         control.append(INPUT(_type="file", _id=field_id, _name=field.name))
         return control
 
@@ -408,9 +420,7 @@ class FormStyleFactory:
                     if isinstance(field, FieldVirtual):
                         field_value = field.f(vars)
                     else:
-                        field_value = (
-                            field.represent and field.represent(value, vars) or value or ""
-                        )
+                        field_value = compat_represent(field, value, vars)
                     field_type = "represent"
                     control = DIV(field_value)
 
@@ -780,6 +790,7 @@ class Form(object):
                 record_id = self.record and self.record.get("id")
                 if not post_vars.get("_delete"):
                     validated_vars = {}
+                    uploaded_fields = set()
                     uploaded_files = []
                     for field in self.table:
                         if field.writable and field.type != "id":
@@ -802,6 +813,7 @@ class Form(object):
                             if field.type == "password" and record_id and value is None:
                                 continue
                             if field.type == "upload":
+                                uploaded_fields.add(field.name)
                                 value = request.files.get(field.name)
                                 delete = post_vars.get("_delete_" + field.name)
                                 if value is not None:
@@ -821,6 +833,14 @@ class Form(object):
                                 validated_vars[field.name] = value
                             if error:
                                 self.errors[field.name] = error
+                    if self.errors:
+                        print("have errors")
+                        for field_name in uploaded_fields:
+                            print(field_name)
+                            validated_vars[field_name] = (
+                                self.record and self.record.get(field_name) or None
+                            )
+                            print(validated_vars[field_name])
                     self.vars.update(validated_vars)
                     if validation:
                         validation(self)
