@@ -8,7 +8,7 @@ import datetime
 from urllib.parse import urlparse
 
 import ombott
-from pydal.objects import Field, FieldVirtual, Expression
+from pydal.objects import Expression, Field, FieldVirtual
 from yatl.helpers import (
     CAT,
     DIV,
@@ -127,9 +127,9 @@ class GridClassStyle:
         "grid-sorter-icon-down": "",
         "grid-thead": "",
         "grid-tr": "",
-        "grid-th": "white-space: nowrap; vertical-align: middle;",
-        "grid-td": "white-space: nowrap; vertical-align: middle;",
-        "grid-td-buttons": "",
+        "grid-th": "text-align:left; white-space: nowrap; vertical-align: top;",
+        "grid-td": "text-align: left; vertical-align: top;",
+        "grid-td-buttons": "text-align: left; white-space: nowrap; vertical-align: top;",
         "grid-button": "margin-bottom: 0;",
         "grid-details-button": "margin-bottom: 0;",
         "grid-edit-button": "margin-bottom: 0;",
@@ -141,17 +141,17 @@ class GridClassStyle:
         "grid-pagination": "display: table-cell; text-align:right;",
         "grid-pagination-button": "min-width: 20px;",
         "grid-pagination-button-current": "min-width: 20px; pointer-events:none; opacity: 0.7;",
-        "grid-cell-type-string": "white-space: nowrap; vertical-align: middle; text-align: left; text-overflow: ellipsis; max-width: 200px;",
-        "grid-cell-type-text": "vertical-align: middle; text-align: left; text-overflow: ellipsis; max-width: 200px;",
-        "grid-cell-type-boolean": "white-space: nowrap; vertical-align: middle; text-align: center;",
-        "grid-cell-type-float": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-decimal": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-int": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-date": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-time": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-datetime": "white-space: nowrap; vertical-align: middle; text-align: right;",
-        "grid-cell-type-upload": "white-space: nowrap; vertical-align: middle; text-align: center;",
-        "grid-cell-type-list": "white-space: nowrap; vertical-align: middle; text-align: left;",
+        "grid-cell-type-string": "white-space: nowrap; vertical-align: top; text-align: left; text-overflow: ellipsis; max-width: 200px;",
+        "grid-cell-type-text": "vertical-align: top; text-align: left; text-overflow: ellipsis; max-width: 200px;",
+        "grid-cell-type-boolean": "white-space: nowrap; vertical-align: top; text-align: center;",
+        "grid-cell-type-float": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-decimal": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-int": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-date": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-time": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-datetime": "white-space: nowrap; vertical-align: top; text-align: right;",
+        "grid-cell-type-upload": "white-space: nowrap; vertical-align: top; text-align: center;",
+        "grid-cell-type-list": "white-space: nowrap; vertical-align: top; text-align: left;",
         # specific for custom form
         "grid-search-form": "",
         "grid-search-form-table": "",
@@ -406,12 +406,17 @@ class Grid:
                               responsible for calling process().
         :param T: optional pluralize object
         """
+        if path in (None, "", "index"):
+            fullpath = request.fullpath.rstrip("/")
+            if path == "index":
+                fullpath = fullpath[:-6]
+            redirect(fullpath + "/select")
 
-        # in case the query is a Table instead
+        # in case the query is a Table insteance
         if isinstance(query, query._db.Table):
             query = query._id != None
 
-        self.path = path or ""
+        self.path = path
         self.db = query._db
         self.T = T
         self.param = Param(
@@ -454,9 +459,7 @@ class Grid:
         #  instance variables that will be computed
         self.action = None
         self.current_page_number = None
-        self.endpoint = request.fullpath
-        if self.path:
-            self.endpoint = self.endpoint[: -len(self.path)].rstrip("/")
+        self.endpoint = request.fullpath[: -len(self.path)].rstrip("/")
         self.hidden_fields = None
         self.form = None
         self.number_of_pages = None
@@ -660,10 +663,11 @@ class Grid:
         elif self.action == "delete" and self.is_deletable(record):
             db(db[self.tablename].id == self.record_id).delete()
 
-            url = parse_referer(request)
-            if url and url.query:
-                self.endpoint += "?%s" % url.query
-            redirect(self.endpoint)
+            rereffer = parse_referer(request)
+            url = self.endpoint + "/select"
+            if referred and referrer.query:
+                url += "?%s" % referrer.query
+            redirect(url)
 
         elif self.action == "select":
             self.referrer = "_referrer=%s" % base64.b16encode(
@@ -956,7 +960,9 @@ class Grid:
     def _make_table_header(self):
         sort_order = request.query.get("orderby", "")
 
-        thead = THEAD(**clean_sc(_class=self.param.grid_class_style.classes.get("grid-thead", "")))
+        thead = THEAD(
+            **clean_sc(_class=self.param.grid_class_style.classes.get("grid-thead", ""))
+        )
         for index, column in enumerate(self.param.columns):
             col = None
             if isinstance(column, (Field, FieldVirtual)):
@@ -1002,12 +1008,12 @@ class Grid:
             col = SPAN(heading)
         elif key == sort_order:
             sort_query_parms["orderby"] = "~" + key
-            url = URL(self.endpoint, vars=sort_query_parms)
+            url = URL(self.endpoint, "select", vars=sort_query_parms)
             attrs = self.attributes_plugin.link(url=url)
             col = A(heading, up, **attrs)
         else:
             sort_query_parms["orderby"] = key
-            url = URL(self.endpoint, vars=sort_query_parms)
+            url = URL(self.endpoint, "select", vars=sort_query_parms)
             attrs = self.attributes_plugin.link(url=url)
             col = A(heading, dw if "~" + key == sort_order else "", **attrs)
         return key, col
@@ -1025,28 +1031,30 @@ class Grid:
         :param field:
         :return:
         """
+        if self.use_tablename:
+            row = row[field.tablename]
         if isinstance(field, FieldVirtual):
-            #  handle virtual fields in table display
-            if self.use_tablename:
-                field_value = field.f(row[field.tablename])
-            else:
-                field_value = field.f(row)
-        elif self.use_tablename:
-            field_value = (
-                field.represent(row[field.tablename][field.name], row[field.tablename])
-                if field.represent
-                else row[field.tablename][field.name]
-            )
+            field_value = field.f(row)
         else:
-            field_value = (
-                field.represent(row[field.name], row) if field.represent else row[field.name]
-            )
+            field_value = row[field.name]
         key = "%s.%s" % (field.tablename, field.name)
-        formatter = (
-            self.formatters.get(key)
-            or self.formatters_by_type.get(field.type)
-            or self.formatters_by_type.get("default")
-        )
+        # custom formatter overwrites represent
+        if key in self.formatters:
+            formatter = self.formatters.get(key)
+        # else if represent provided use it
+        elif field.represent:
+            formatter = field.represent
+        # else fallback on the formatter for the type
+        elif field.type in self.formatters_by_type:
+            formatter = self.formatters_by_type.get(field.type)
+        # else fallback to default
+        else:
+            formatter = self.formatters_by_type.get("default")
+        # allow 1 (value) or 2 (value + row) args
+        try:
+            formatted_value = formatter(field_value, row)
+        except TypeError:
+            formatted_value = formatter(field_value)
 
         class_type = "grid-cell-type-%s" % str(field.type).split(":")[0].split("(")[0]
         class_col = " grid-col-%s" % key.replace(".", "_")
@@ -1056,15 +1064,13 @@ class Grid:
             class_col,
         )
         td = TD(
-            formatter(field_value)
-            if formatter.__code__.co_argcount == 1  # if formatter has only 1 argument
-            else formatter(field_value, row),
+            formatted_value,
             **clean_sc(
                 _class=classes,
                 _style=(
-                        self.param.grid_class_style.styles.get(class_type)
-                        or self.param.grid_class_style.styles.get("grid-td")
-                )
+                    self.param.grid_class_style.styles.get(class_type)
+                    or self.param.grid_class_style.styles.get("grid-td")
+                ),
             ),
         )
 
@@ -1090,9 +1096,13 @@ class Grid:
             tr = TR(
                 _role="row",
                 **clean_sc(
-                    _class=join_classes(self.param.grid_class_style.classes.get("grid-tr"), extra_class),
-                    _style=join_styles([self.param.grid_class_style.styles.get("grid-tr"), extra_style]),
-                )
+                    _class=join_classes(
+                        self.param.grid_class_style.classes.get("grid-tr"), extra_class
+                    ),
+                    _style=join_styles(
+                        [self.param.grid_class_style.styles.get("grid-tr"), extra_style]
+                    ),
+                ),
             )
             #  add all the fields to the row
             for index, column in enumerate(self.param.columns):
@@ -1110,7 +1120,10 @@ class Grid:
                         self.param.grid_class_style.styles.get("grid-td"),
                     )
                     tr.append(
-                        TD(column.render(row, index), **clean_sc(_class=classes, _style=style))
+                        TD(
+                            column.render(row, index),
+                            **clean_sc(_class=classes, _style=style),
+                        )
                     )
 
             td = None
@@ -1263,7 +1276,7 @@ class Grid:
                 else "grid-pagination-button"
             )
             attrs = self.attributes_plugin.link(
-                url=URL(self.endpoint, vars=pager_query_parms)
+                url=URL(self.endpoint, "select", vars=pager_query_parms)
             )
             pager.append(
                 A(
